# pygments.lexers.graphql

A GraphQL lexer for [Pygments].

This is just a pip-installable version of this gist: <https://gist.github.com/owulveryck/17a049d413ff8e3affa9c68a3010a089>

  [Pygments]: http://pygments.org
